#[non_exhaustive]pub enum SaveError {
InvalidMagic {
offset: usize,
found: u32,
},
DecompressionFailed {
offset: usize,
message: String,
},
UnexpectedEof {
offset: usize,
expected: usize,
},
ChunkTooLarge {
offset: usize,
declared: u32,
},
InvalidMetaLength {
length: usize,
},
MetaDecryptionFailed,
UnsupportedMetaFormat {
version: u32,
},
Sha256Mismatch {
expected: [u8; 32],
actual: [u8; 32],
},
MappingParseError {
message: String,
},
JsonParseError {
message: String,
},
Io(Error),
}Expand description
Error returned by save file decompression and parsing operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidMagic
Block header magic mismatch.
DecompressionFailed
LZ4 decompression failed for a block.
UnexpectedEof
File ended before the expected number of bytes could be read.
ChunkTooLarge
A block’s decompressed_size exceeds the maximum chunk size.
InvalidMetaLength
Metadata file has an invalid length (not one of the known sizes).
MetaDecryptionFailed
Metadata decryption failed – magic sentinel not found after trying all slots.
UnsupportedMetaFormat
Metadata format version is unsupported (e.g., 2000/vanilla).
Sha256Mismatch
SHA-256 verification failed.
MappingParseError
Failed to parse a mapping JSON file.
JsonParseError
Failed to parse save JSON.
Io(Error)
Wrapper for std::io::Error (file I/O).